@@ -4,7 +4,7 @@
 # imports.
 from fir3base.v1.classes.config import *
 from fir3base.v1.classes import utils
-
+from firebase_admin import _auth_utils
 # the firebase class.
 class Firebase(object):
 	def __init__(self, key=None):
@@ -28,6 +28,9 @@ class Users(object):
 		self.smtp_host = "smtp.gmail.com"
 		self.smtp_port = 587
 
+		# system variables.
+		self.verification_codes = {}
+
 		#
 	def get(self, 
 		# define one of the following parameters.
@@ -35,18 +38,21 @@ class Users(object):
 		email=None,
 		phone_number=None,
 	):
-		user, variable = None, None
-		if uid != None:
-			user = auth.get_user(uid)
-			variable = str(uid)
-		elif email != None:
-			user = auth.get_user_by_email(email)
-			variable = str(email)
-		elif phone_number != None:
-			user = auth.get_user_by_phone_number(phone_number)
-			variable = str(phone_number)
-		else:
-			return r3sponse.error_response("Invalid usage, define one of the following parameters: [uid, email, phone_number].")
+		try:
+			user, variable = None, None
+			if uid != None:
+				user = auth.get_user(uid)
+				variable = str(uid)
+			elif email != None:
+				user = auth.get_user_by_email(email)
+				variable = str(email)
+			elif phone_number != None:
+				user = auth.get_user_by_phone_number(phone_number)
+				variable = str(phone_number)
+			else:
+				return r3sponse.error_response("Invalid usage, define one of the following parameters: [uid, email, phone_number].")
+		except _auth_utils.UserNotFoundError:
+			return r3sponse.error_response("User does not exist.")
 
 		# check success.
 		if user == None: 
@@ -128,7 +134,7 @@ class Users(object):
 		})
 
 		# load.
-		response = self.get(uid=uid)
+		response = self.get(uid=uid, email=email)
 		if response["error"] != None: return response
 		user = response["user"]
 
